##  Claiming and Assigning To-Dos
Claim a to-do to take ownership of the task. This indicates to others that the task is claimed and prevents multiple people from working on it at the same time.
**Note**
Claiming a task is not a requirement for completing a task.
Any user can claim a to-do item unless the administrator has restricted it. To learn more, see [Restricting To-Do Completion to Assignees](https://help.sap.com/docs/leanix/ea/to-dos?locale=en-US&state=PRODUCTION&version=CLOUD#loio275ad8677a441014bd85fc1784a4ff30__restricting_to-do_completion_to_assignees)
If no assignees are initially assigned to a task, any user can assign it to an appropriate person. This ensures responsibility is clearly assigned. Assignees can also be changed or additional ones added as needed.
**Note**
Having an assignee is not a requirement for completing a task.
To claim or assign a to-do, select the to-do item and chooseClaim or Select Assignees.
![Claiming and assigning to-dos in the application interface](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio85e128121e814f4d8f8d12c7d8ec4ac6_LowRes.png)
Claiming and Assigning To-Dos
